@@ -525,6 +525,8 @@ browse_clicked(GnomeFileEntry *fentry, GnomeIconEntry *ientry)
 	fs = GTK_FILE_SELECTION(fentry->fsw);
 
 	hbox = fs->file_list;
+	g_return_if_fail (g_object_get_data(G_OBJECT(hbox),"frame") == NULL);
+
 	do {
 		hbox = hbox->parent;
 		if(!hbox) {
@@ -719,7 +721,11 @@ ientry_browse(GnomeIconEntry *ientry)
 		}
 	}
 
-
+	/* If the parent of GnomeIconEntry is a modal window,
+	 * the GnomeFileEntry should also be modal dialog.
+	 */
+	if (GTK_WINDOW (tl)->modal)
+		gnome_file_entry_set_modal (GNOME_FILE_ENTRY(priv->fentry), TRUE);
 	if(priv->pick_dialog==NULL ||
 	   priv->pick_dialog_dir==NULL ||
 	   strcmp(p,priv->pick_dialog_dir)!=0) {
@@ -767,8 +773,6 @@ ientry_browse(GnomeIconEntry *ientry)
 
 		gtk_widget_show_all(priv->pick_dialog);
 
-		gnome_icon_selection_show_icons(GNOME_ICON_SELECTION(priv->icon_sel));
-
 		g_signal_connect (priv->pick_dialog, "response",
 				  G_CALLBACK (dialog_response),
 				  ientry);
@@ -777,6 +781,8 @@ ientry_browse(GnomeIconEntry *ientry)
 		g_signal_connect_after (gil, "select_icon",
 					G_CALLBACK (gil_icon_selected_cb),
 					ientry);
+		gnome_icon_selection_show_icons(GNOME_ICON_SELECTION(priv->icon_sel));
+
 	} else {
 		gtk_window_present (GTK_WINDOW (priv->pick_dialog));
 
