@@ -66,6 +66,7 @@
 #include <gtk/gtkentry.h>
 #include <gtk/gtktogglebutton.h>
 #include <gtk/gtkcheckmenuitem.h>
+#include <gtk/gtkmessagedialog.h>
 
 /*****************************************************************************
  * libgnomeui
@@ -286,6 +287,83 @@ libgnomeui_pre_args_parse(GnomeProgram *app, GnomeModuleInfo *mod_info)
 }
 
 #ifdef HAVE_ESD
+static gboolean
+relay_gnome_signal (GSignalInvocationHint *hint,
+              	     guint n_param_values,
+                    const GValue *param_values,
+                    gchar *signame)
+{
+        char *pieces[3] = {"gnome-2", NULL, NULL};
+        static GQuark disable_sound_quark = 0;
+        GObject *object = g_value_get_object (&param_values[0]);
+
+        if (!use_event_sounds)
+                return TRUE;
+
+        if (!disable_sound_quark)
+                disable_sound_quark = g_quark_from_static_string ("gnome_disable_sound_events");
+
+        if (g_object_get_qdata (object, disable_sound_quark))
+                return TRUE;
+
+        if (GTK_IS_WIDGET (object)) {
+
+                if (!GTK_WIDGET_DRAWABLE (object))
+                        return TRUE;
+
+                if (GTK_IS_MESSAGE_DIALOG (object)) {
+                        GtkMessageType message_type;
+                        g_object_get (object, "message_type", &message_type, NULL);
+                        switch (message_type)
+                        {
+                                case GTK_MESSAGE_INFO:
+                                        pieces[1] = "info";
+                                        break;
+
+                                case GTK_MESSAGE_QUESTION:
+                                        pieces[1] = "question";
+                                        break;
+
+                                case GTK_MESSAGE_WARNING:
+                                        pieces[1] = "warning";
+                                        break;
+
+                                case GTK_MESSAGE_ERROR:
+                                        pieces[1] = "error";
+                                        break;
+
+                                default:
+                                        pieces[1] = NULL;
+                        }
+                }
+        }
+
+        if (gnome_sound_connection_get () < 0)
+                return TRUE;
+
+        gnome_triggers_vdo ("", NULL, (const char **) pieces);
+
+        return TRUE;
+}
+
+static void
+initialize_gnome_signal_relay (void)
+{
+        static gboolean initialized = FALSE;
+        int signum;
+
+        if (initialized)
+                return;
+
+        initialized = TRUE;
+
+        signum = g_signal_lookup ("show", GTK_TYPE_MESSAGE_DIALOG);
+        g_signal_add_emission_hook (signum, 0,
+                                    (GSignalEmissionHook) relay_gnome_signal,
+                                    NULL, NULL);
+
+}
+
 static gboolean
 relay_gtk_signal(GSignalInvocationHint *hint,
 		 guint n_param_values,
@@ -315,41 +393,26 @@ relay_gtk_signal(GSignalInvocationHint *hint,
       return TRUE;
   }
 
+  if (gnome_sound_connection_get() < 0)
+    return TRUE;
+
   gnome_triggers_vdo("", NULL, (const char **)pieces);
 
   return TRUE;
 }
-#endif
-
-/* Callback used when the GConf event_sounds key's value changes */
-static void
-event_sounds_changed_cb (GConfClient* client, guint cnxn_id, GConfEntry *entry, gpointer data)
-{
-        use_event_sounds = gconf_value_get_bool (entry->value);
-}
 
 static void
 initialize_gtk_signal_relay (void)
 {
-#ifdef HAVE_ESD
 	gpointer iter_signames;
 	char *signame;
 	char *ctmp, *ctmp2;
-	
-	if (gnome_sound_connection_get () < 0)
-		return;
+        static gboolean initialized = FALSE;
 
-        gconf_client = gconf_client_get_default ();
-        if (!gconf_client)
+        if (initialized)
                 return;
 
-        gconf_client_add_dir (gconf_client, "/desktop/gnome/sound", GCONF_CLIENT_PRELOAD_NONE, NULL);
-
-        gconf_client_notify_add (gconf_client, "/desktop/gnome/sound/event_sounds",
-                                 event_sounds_changed_cb,
-                                 NULL, NULL, NULL);
-	
-        use_event_sounds = gnome_gconf_get_bool ("/desktop/gnome/sound/event_sounds");
+        initialized = TRUE;
 	
 	ctmp = gnome_config_file ("/sound/events/gtk-events-2.soundlist");
 	ctmp2 = g_strconcat ("=", ctmp, "=", NULL);
@@ -369,14 +432,14 @@ initialize_gtk_signal_relay (void)
 		 * knowledge of what gtk widgets do what, rather than
 		 * anything based on the info available at runtime.
 		 */
-		if(!strcmp (signame, "activate")){
+		if (!strcmp (signame, "activate")) {
 			g_type_class_unref (g_type_class_ref (gtk_menu_item_get_type ()));
 			signums [0] = g_signal_lookup (signame, gtk_menu_item_get_type ());
 			
 			g_type_class_unref (g_type_class_ref (gtk_entry_get_type ()));
 			signums [1] = g_signal_lookup (signame, gtk_entry_get_type ());
 			nsigs = 2;
-		} else if(!strcmp(signame, "toggled")){
+		} else if (!strcmp(signame, "toggled")) {
 			g_type_class_unref (g_type_class_ref (gtk_toggle_button_get_type ()));
 			signums [0] = g_signal_lookup (signame,
 							 gtk_toggle_button_get_type ());
@@ -385,7 +448,7 @@ initialize_gtk_signal_relay (void)
 			signums [1] = g_signal_lookup (signame,
 							 gtk_check_menu_item_get_type ());
 			nsigs = 2;
-		} else if (!strcmp (signame, "clicked")){
+		} else if (!strcmp (signame, "clicked")) {
 			g_type_class_unref (g_type_class_ref (gtk_button_get_type ()));
 			signums [0] = g_signal_lookup (signame, gtk_button_get_type ());
 			nsigs = 1;
@@ -396,19 +459,65 @@ initialize_gtk_signal_relay (void)
 		}
 
 		used_signame = FALSE;
-		for(i = 0; i < nsigs; i++) {
+		for (i = 0; i < nsigs; i++) {
 			if (signums [i] > 0) {
-				g_signal_add_emission_hook (signums [i], 0,
-							      (GSignalEmissionHook)relay_gtk_signal,
-							      signame, NULL);
+				g_signal_add_emission_hook (
+                                        signums [i], 0,
+                                        (GSignalEmissionHook) relay_gtk_signal,
+                                        signame, NULL);
                                 used_signame = TRUE;
                         }
                 }
 
-                if(!used_signame)
-                        g_free(signame);
+                if (!used_signame)
+                        g_free (signame);
 	}
 	gnome_config_pop_prefix ();
+}
+
+/* Callback used when the GConf event_sounds key's value changes */
+static void
+event_sounds_changed_cb (GConfClient* client, guint cnxn_id, GConfEntry *entry, gpointer data)
+{
+        gboolean new_use_event_sounds;
+
+        new_use_event_sounds = (gnome_gconf_get_bool ("/desktop/gnome/sound/enable_esd") &&
+                                gnome_gconf_get_bool ("/desktop/gnome/sound/event_sounds"));
+
+        if (new_use_event_sounds && !use_event_sounds) {
+                initialize_gtk_signal_relay ();
+                initialize_gnome_signal_relay ();
+	}
+
+        use_event_sounds = new_use_event_sounds;
+}
+#endif
+
+static void
+setup_event_listener (void)
+{
+#ifdef HAVE_ESD
+        gconf_client = gconf_client_get_default ();
+        if (!gconf_client)
+                return;
+
+        gconf_client_add_dir (gconf_client, "/desktop/gnome/sound",
+                              GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
+
+        gconf_client_notify_add (gconf_client, "/desktop/gnome/sound/event_sounds",
+                                 event_sounds_changed_cb,
+                                 NULL, NULL, NULL);
+        gconf_client_notify_add (gconf_client, "/desktop/gnome/sound/enable_esd",
+                                 event_sounds_changed_cb,
+                                 NULL, NULL, NULL);
+	
+        use_event_sounds = (gnome_gconf_get_bool ("/desktop/gnome/sound/enable_esd") &&
+                            gnome_gconf_get_bool ("/desktop/gnome/sound/event_sounds"));
+
+        if (use_event_sounds) {
+                initialize_gtk_signal_relay ();
+                initialize_gnome_signal_relay ();
+	 }
 #endif
 }
 
@@ -440,7 +549,7 @@ libgnomeui_post_args_parse(GnomeProgram *program, GnomeModuleInfo *mod_info)
 
         _gnome_stock_icons_init ();
 
-	initialize_gtk_signal_relay ();
+        setup_event_listener ();
 }
 
 static void
@@ -560,27 +669,28 @@ libgnomeui_segv_setup (GnomeProgram *program, gboolean post_arg_parse)
         do_crash_dialog = g_value_get_boolean (&value);
         g_value_unset (&value);
 
-        memset(&sa, 0, sizeof(sa));
-
-        setptr = &sa;
         if(do_crash_dialog) {
+                memset(&sa, 0, sizeof(sa));
+                setptr = &sa;
+
                 sa.sa_handler = (gpointer)libgnomeui_segv_handle;
-        } else {
-                sa.sa_handler = SIG_DFL;
+
+                sigaction(SIGSEGV, setptr, NULL);
+                sigaction(SIGABRT, setptr, NULL);
+                sigaction(SIGTRAP, setptr, NULL);
+                sigaction(SIGFPE, setptr, NULL);
+                sigaction(SIGBUS, setptr, NULL);
         }
 
-        sigaction(SIGSEGV, setptr, NULL);
-        sigaction(SIGABRT, setptr, NULL);
-        sigaction(SIGTRAP, setptr, NULL);
-        sigaction(SIGFPE, setptr, NULL);
-        sigaction(SIGBUS, setptr, NULL);
 }
 
 static void libgnomeui_segv_handle(int signum)
 {
 	static int in_segv = 0;
+        struct sigaction sa;
 	pid_t pid;
 	
+	sa.sa_handler = NULL;
 	in_segv++;
 
         if (in_segv > 2) {
@@ -606,8 +716,12 @@ static void libgnomeui_segv_handle(int signum)
 				   "Cannot display crash dialog\n"));
 
                 /* Don't use app attributes here - a lot of things are probably hosed */
-		if (g_getenv ("GNOME_DUMP_CORE"))
+		if (g_getenv ("GNOME_DUMP_CORE")) {
+                        /* Reset SIGABRT so we don't get called again. */
+                        sa.sa_handler = SIG_DFL;
+                        sigaction (SIGABRT, &sa, NULL);
 	                abort ();
+                }
 
 		_exit(1);
 	} else if (pid > 0) {
@@ -620,8 +734,12 @@ static void libgnomeui_segv_handle(int signum)
 		eret = waitpid(pid, &estatus, 0);
 
                 /* Don't use app attributes here - a lot of things are probably hosed */
-		if(g_getenv("GNOME_DUMP_CORE"))
+		if(g_getenv("GNOME_DUMP_CORE")) {
+                        /* Reset SIGABRT so we don't get called again. */
+                        sa.sa_handler = SIG_DFL;
+                        sigaction (SIGABRT, &sa, NULL);
 	                abort ();
+                }
 
 		_exit(1);
 	} else /* pid == 0 */ {
